@@ -3,19 +3,17 @@
     Copyright (C) 2007 Lubos Lunak (l.lunak@kde.org)
 
     This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
+    modify it under the terms of the GNU Lesser General Public
     License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+    version 2.1 of the License, or (at your option) any later version.
 
     This library is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
+    Lesser General Public License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 /*
  * kwindowsystem.h. Part of the KDE project.
@@ -31,6 +29,7 @@
 #include <kwindowinfo.h>
 
 class KWindowSystemPrivate;
+class NETWinInfo;
 
 /**
  *
@@ -72,11 +71,10 @@ public:
       *
       * Iteration over this list can be done easily with
       * \code
-      *  QList<WId>::ConstIterator it;
-      *  for ( it = KWindowSystem::windows().begin();
-      *        it != KWindowSystem::windows().end(); ++it ) {
+      *  QList<WId> windows = KWindowSystem::windows();
+      *  for (auto it = windows.cbegin(), end = windows.cend(); it != end; ++it) {
       *     ... do something here,  (*it) is the current WId.
-      *       }
+      *  }
       * \endcode
       * @return the list of all toplevel windows
       */
@@ -215,6 +213,17 @@ public:
      */
     static void setOnDesktop(WId win, int desktop);
 
+    /**
+     * Moves window @p win to activities @p activities.
+     *
+     * @param win the id of the window
+     * @param activities the list of activity UUIDs
+     *
+     * @since 5.1
+     * @see KWindowInfo::activities
+     */
+    static void setOnActivities(WId win, const QStringList &activities);
+
     /**
      * Sets the parent window of @p subwindow to be @p mainwindow.
      * This overrides the parent set the usual way as the QWidget parent,
@@ -291,6 +300,31 @@ public:
      */
     static QPixmap icon(WId win, int width, int height, bool scale, int flags);
 
+    /**
+     * @overload
+     *
+     * Overloaded variant that allows passing in the NETWinInfo to use for reading the
+     * information. This variant is only useful on the X11 platform, other platforms do not
+     * use NETWinInfo and delegate to the variant without NETWinInfo. Though if compiled with
+     * X11 support the X11 variant is used on other platforms if info is not @c nullptr.
+     * This can be used by applications using e.g. platform wayland but also connecting to an
+     * XServer.
+     *
+     * The NETWinInfo must be constructed with property NET::WMIcon in order to use the
+     * IconSource flag NETWM. NET::WM2IconPixmap for IconSource flag WMHints and
+     * NET::WM2WindowClass for IconSource flag ClassHint.
+     *
+     * @param win the id of the window
+     * @param width the desired width, or -1
+     * @param height the desired height, or -1
+     * @param scale if true the icon will be scaled to the desired size. Otherwise the
+     *        icon will not be modified.
+     * @param flags OR-ed flags from the IconSource enum
+     * @param into the NETWinInfo to use for reading properties.
+     * @since 5.7
+     **/
+    static QPixmap icon(WId win, int width, int height, bool scale, int flags, NETWinInfo *info);
+
     /**
      * Sets an @p icon and a  @p miniIcon on window @p win
      * @param win the id of the window
@@ -332,24 +366,35 @@ public:
     static void clearState(WId win, NET::States  state);
 
     /**
-     * Iconifies a window. Compatible to XIconifyWindow but has an
-     * additional parameter @p animation.
+     * Minimizes the window with id @p win.
+     * On X11 this follows the protocol described in ICCCM section 4.1.4.
      *
-     * @param win the id of the window
-     * @param animation true to show an animation
-     * @see deIconifyWindow()
+     * @param win The window to minimize
+     * @see unminimizeWindow()
      */
-    static void minimizeWindow(WId win, bool animation = true);
+    static void minimizeWindow(WId win);
+    /**
+     * Unminimizes the window with id @p win.
+     * On X11 this follows the protocol described in ICCCM section 4.1.4.
+     *
+     * @param win The window to unminimize
+     * @see minimizeWindow()
+     **/
+    static void unminimizeWindow(WId win);
 
     /**
-     * DeIconifies a window. Compatible to XMapWindow but has an
-     * additional parameter @p animation.
-     *
-     * @param win the id of the window
-     * @param animation true to show an animation
-     * @see iconifyWindow()
+     * @deprecated since 5.0 the @p animation is ignored.
      */
-    static void unminimizeWindow(WId win, bool animation = true);
+#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+    static void minimizeWindow(WId win, bool animation);
+#endif
+
+    /**
+     * @deprecated since 5.0 the @p animation is ignored.
+     */
+#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+    static void unminimizeWindow(WId win, bool animation);
+#endif
 
     /**
      * Raises the given window. This call is only for pagers and similar
@@ -414,6 +459,17 @@ public:
      */
     static bool showingDesktop();
 
+    /**
+     * Sets the state of the "showing desktop" mode of the window manager. If on,
+     * windows are hidden and desktop background is shown and focused.
+     *
+     * @param showing if true, the window manager is put in "showing desktop" mode.
+     * If false, the window manager is put out of that mode.
+     *
+     * @since 5.7.0
+     */
+    static void setShowingDesktop(bool showing);
+
     /**
      * Sets user timestamp @p time on window @p win. The timestamp
      * is expressed as XServer time. If a window
@@ -646,7 +702,7 @@ Q_SIGNALS:
     void compositingChanged(bool enabled);
 
 protected:
-    virtual void connectNotify(const QMetaMethod &signal) Q_DECL_OVERRIDE;
+    void connectNotify(const QMetaMethod &signal) Q_DECL_OVERRIDE;
 
 private:
     friend class KWindowSystemStaticContainer;
